@@ -72,6 +72,8 @@ public:
     bool resizable = false;
     bool acceptFocus = true;
     bool modality = false;
+    bool splitable = false;
+    bool onAllDesktops = false;
 
     static DDEShellSurface *get(wl_surface *surface);
     static DDEShellSurface *get(Surface *surface);
@@ -79,12 +81,14 @@ public:
 private:
     static void geometryCallback(void *data, dde_shell_surface *dde_shell_surface, int32_t x, int32_t y, uint32_t width, uint32_t height);
     static void stateChangedCallback(void *data, dde_shell_surface *dde_shell_surface, uint32_t state);
+    static void splitableCallback(void *data, dde_shell_surface *dde_shell_surface, uint32_t splitable);
     void setActive(bool set);
     void setMinimized(bool set);
     void setMaximized(bool set);
     void setFullscreen(bool set);
     void setKeepAbove(bool set);
     void setKeepBelow(bool set);
+    void setOnAllDesktops(bool set);
     void setCloseable(bool set);
     void setMinimizeable(bool set);
     void setMaximizeable(bool set);
@@ -261,6 +265,7 @@ void DDEShellSurface::Private::stateChangedCallback(void *data, dde_shell_surfac
     p->setFullscreen(state & DDE_SHELL_STATE_FULLSCREEN);
     p->setKeepAbove(state & DDE_SHELL_STATE_KEEP_ABOVE);
     p->setKeepBelow(state & DDE_SHELL_STATE_KEEP_BELOW);
+    p->setOnAllDesktops(state & DDE_SHELL_STATE_ON_ALL_DESKTOPS);
     p->setCloseable(state & DDE_SHELL_STATE_CLOSEABLE);
     p->setFullscreenable(state & DDE_SHELL_STATE_FULLSCREENABLE);
     p->setMaximizeable(state & DDE_SHELL_STATE_MAXIMIZABLE);
@@ -283,9 +288,18 @@ void DDEShellSurface::Private::geometryCallback(void *data, dde_shell_surface *d
     emit p->q->geometryChanged(geo);
 }
 
+void DDEShellSurface::Private::splitableCallback(void *data, dde_shell_surface *ddeShellSurface, uint32_t splitable)
+{
+    Q_UNUSED(ddeShellSurface)
+    Private *p = cast(data);
+
+    p->splitable = splitable;
+}
+
 const dde_shell_surface_listener DDEShellSurface::Private::s_listener = {
     geometryCallback,
     stateChangedCallback,
+    splitableCallback,
 };
 
 void DDEShellSurface::Private::setActive(bool set)
@@ -297,6 +311,15 @@ void DDEShellSurface::Private::setActive(bool set)
     emit q->activeChanged();
 }
 
+void DDEShellSurface::Private::setOnAllDesktops(bool set)
+{
+    if (onAllDesktops == set) {
+        return;
+    }
+    onAllDesktops = set;
+    emit q->onAllDesktopsChanged();
+}
+
 void DDEShellSurface::Private::setFullscreen(bool set)
 {
     if (fullscreen == set) {
@@ -598,6 +621,24 @@ void DDEShellSurface::requestResizable(bool set)
     }
 }
 
+void DDEShellSurface::requestOnAllDesktops(bool set)
+{
+    if (!set) {
+        dde_shell_surface_set_state(d->ddeShellSurface,
+            DDE_SHELL_STATE_ON_ALL_DESKTOPS,
+            0);
+    } else {
+        dde_shell_surface_set_state(d->ddeShellSurface,
+            DDE_SHELL_STATE_ON_ALL_DESKTOPS,
+            DDE_SHELL_STATE_ON_ALL_DESKTOPS);
+    }
+}
+
+bool DDEShellSurface::isOnAllDesktops() const
+{
+    return d->onAllDesktops;
+}
+
 bool DDEShellSurface::isActive() const
 {
     return d->active;
@@ -668,6 +709,11 @@ bool DDEShellSurface::isMovable() const
     return d->movable;
 }
 
+bool DDEShellSurface::isSplitable() const
+{
+    return d->splitable;
+}
+
 QRect DDEShellSurface::getGeometry() const
 {
     return d->geometry;
@@ -700,5 +746,19 @@ void DDEShellSurface::requestWindowRadiusProperty(QPointF windowRadius)
     wl_array_release(&arr);
 }
 
+void DDEShellSurface::requestSplitWindow(DDEShellSurface::SplitType splitType)
+{
+    switch (splitType) {
+    case SplitType::leftSplit:
+        dde_shell_surface_request_split_window(d->ddeShellSurface, DDE_SHELL_SPLIT_TYPE_LEFT_SPLIT);
+        break;
+    case SplitType::rightSplit:
+        dde_shell_surface_request_split_window(d->ddeShellSurface, DDE_SHELL_SPLIT_TYPE_RIGHT_SPLIT);
+        break;
+    default:
+        break;
+    }
+}
+
 }
 }
